Crate flawless_utils

Crate flawless_utils 

A set of utilities that help you integrate native Rust projects with Flawless workflows.

Check out the docs at https://flawless.dev/docs/integration-with-rust

Macros

load_module_from_build

Structs

DeployedModule
Server
Represents an instance of a flawless server.
WorkflowRef

Functions

build_debug
Builds the flawless module located in the workflows directory in debug mode.
build_release
Builds the flawless module located in the workflows directory in release mode.